@@ -550,7 +550,7 @@ BOOL DrawView::IsObjMarkable(SdrObject* pObj, SdrPageView* pPV) const
 
 void DrawView::MakeVisible(const Rectangle& rRect, ::Window& rWin)
 {
-    if (!rRect.IsEmpty())
+    if (!rRect.IsEmpty() && mpDrawViewShell)
     {
         mpDrawViewShell->MakeVisible(rRect, rWin);
     }
